@@ -593,6 +593,8 @@ ORBit_small_invoke_stub (CORBA_Object       obj,
 	ORBitPolicy            *invoke_policy = CORBA_OBJECT_NIL;
 	gboolean                timeout = FALSE;
 
+	CORBA_exception_init (ev);
+
 	if (!obj) {
 		dprintf (MESSAGES, "Cannot invoke method on null object\n");
 		CORBA_exception_set_system (ev, ex_CORBA_INV_OBJREF,
@@ -600,8 +602,6 @@ ORBit_small_invoke_stub (CORBA_Object       obj,
 		goto clean_out;
 	}
 
-	CORBA_exception_init (ev);
-
 	if ((invoke_policy = ORBit_object_get_policy (obj)))
 		ORBit_policy_push (invoke_policy);
 
@@ -1149,6 +1149,11 @@ async_recv_cb (ORBitAsyncQueueEntry *aqe)
 		CORBA_exception_set_system (ev, ex_CORBA_COMM_FAILURE,
 					    aqe->completion_status);
 
+	if (aqe->mqe.cnx &&
+	    aqe->mqe.cnx->parent.status == LINK_TIMEOUT)
+		CORBA_exception_set_system (ev, ex_CORBA_TIMEOUT,
+					    aqe->completion_status);
+
 	if (aqe->fn)
 		aqe->fn (aqe->obj, aqe->m_data, aqe, aqe->user_data, ev);
 
